# load_floz

Python package to load `.floz` files saved by [FLO](https://github.com/strawlab/flo).

## Installation

```bash
pip install load_floz
```

## Developers: building and publishing a release

Build a release:

```bash
python3 -m pip install build
python3 -m build
```

Publish release:
